==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/features/sharding/core/src/test/java/org/apache/shardingsphere/sharding/yaml/swapper/rule/YamlShardingTableReferenceRuleConfigurationConverterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.yaml.swapper.rule;

import org.apache.shardingsphere.sharding.api.config.rule.ShardingTableReferenceRuleConfiguration;
import org.junit.jupiter.api.Test;

import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class YamlShardingTableReferenceRuleConfigurationConverterTest {
    
    @Test
    void assertConvertToYamlString() {
        ShardingTableReferenceRuleConfiguration data = new ShardingTableReferenceRuleConfiguration("foo", "LOGIC_TABLE,SUB_LOGIC_TABLE");
        String actual = YamlShardingTableReferenceRuleConfigurationConverter.convertToYamlString(data);
        assertThat(actual, is("foo:LOGIC_TABLE,SUB_LOGIC_TABLE"));
    }
    
    @Test
    void assertConvertToObjectForYamlConfigurationWithName() {
        ShardingTableReferenceRuleConfiguration actual = YamlShardingTableReferenceRuleConfigurationConverter.convertToObject("foo:LOGIC_TABLE,SUB_LOGIC_TABLE");
        assertThat(actual.getName(), is("foo"));
        assertThat(actual.getReference(), is("LOGIC_TABLE,SUB_LOGIC_TABLE"));
    }
    
    @Test
    void assertConvertToObjectForYamlConfigurationWithoutName() {
        ShardingTableReferenceRuleConfiguration actual = YamlShardingTableReferenceRuleConfigurationConverter.convertToObject("LOGIC_TABLE,SUB_LOGIC_TABLE");
        assertThat(actual.getReference(), is("LOGIC_TABLE,SUB_LOGIC_TABLE"));
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/features/sharding/core/src/test/java/org/apache/shardingsphere/sharding/yaml/swapper/rule/YamlShardingTableReferenceRuleConfigurationConverterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.yaml.swapper.rule;

import org.apache.shardingsphere.sharding.api.config.rule.ShardingTableReferenceRuleConfiguration;
import org.junit.jupiter.api.Test;

import static org.hamcrest.Matchers.is;
import static org.hamcrest.MatcherAssert.assertThat;

class YamlShardingTableReferenceRuleConfigurationConverterTest {
    
    @Test
    void assertConvertToYamlString() {
        ShardingTableReferenceRuleConfiguration data = new ShardingTableReferenceRuleConfiguration("foo", "LOGIC_TABLE,SUB_LOGIC_TABLE");
        String actual = YamlShardingTableReferenceRuleConfigurationConverter.convertToYamlString(data);
        assertThat(actual, is("foo:LOGIC_TABLE,SUB_LOGIC_TABLE"));
    }
    
    @Test
    void assertConvertToObjectForYamlConfigurationWithName() {
        ShardingTableReferenceRuleConfiguration actual = YamlShardingTableReferenceRuleConfigurationConverter.convertToObject("foo:LOGIC_TABLE,SUB_LOGIC_TABLE");
        assertThat(actual.getName(), is("foo"));
        assertThat(actual.getReference(), is("LOGIC_TABLE,SUB_LOGIC_TABLE"));
    }
    
    @Test
    void assertConvertToObjectForYamlConfigurationWithoutName() {
        ShardingTableReferenceRuleConfiguration actual = YamlShardingTableReferenceRuleConfigurationConverter.convertToObject("LOGIC_TABLE,SUB_LOGIC_TABLE");
        assertThat(actual.getReference(), is("LOGIC_TABLE,SUB_LOGIC_TABLE"));
    }
}
